@@ -20,11 +20,12 @@
 #define EXTRAICONPATH ""
 
 #define R__HAS_SETRESUID   /**/
-#define R__HAS_MATHMORE   /**/
+#undef R__HAS_MATHMORE   /**/
 #define R__HAS_PTHREAD    /**/
 #define R__HAS_XFT    /**/
 #undef R__HAS_COCOA    /**/
 #undef R__HAS_VC    /**/
+#define R__HAS_VDT    /**/
 #undef R__HAS_VECCORE    /**/
 #define R__USE_CXX11    /**/
 #undef R__USE_CXX14    /**/
@@ -36,10 +37,13 @@
 #undef R__HAS_STOD_STRING_VIEW /**/
 #undef R__HAS_STD_APPLY /**/
 #undef R__HAS_STD_INVOKE /**/
+#undef R__HAS_STD_INDEX_SEQUENCE /**/
 #define R__HAS_ATTRIBUTE_ALWAYS_INLINE /**/
 #undef R__EXTERN_LLVMDIR /**/
 #define R__USE_IMT   /**/
 #undef R__COMPLETE_MEM_TERMINATION /**/
+#undef R__HAS_CEFWEB  /**/
+#undef R__HAS_QT5WEB  /**/
 
 #if defined(R__HAS_VECCORE) && defined(R__HAS_VC)
 #ifndef VECCORE_ENABLE_VC
@@ -47,4 +51,11 @@
 #endif
 #endif
 
+#define R__HAS_DEFAULT_LZ4  /**/
+#undef R__HAS_DEFAULT_ZLIB  /**/
+#undef R__HAS_DEFAULT_LZMA  /**/
+
+#undef R__HAS_TMVACPU /**/
+#undef R__HAS_TMVAGPU /**/
+
 #endif
